Struct www_authenticate::DigestChallenge
[−]
[src]
pub struct DigestChallenge {
pub realm: Option<String>,
pub domain: Option<Vec<Url>>,
pub nonce: Option<String>,
pub opaque: Option<String>,
pub stale: Option<bool>,
pub algorithm: Option<Algorithm>,
pub qop: Option<Vec<Qop>>,
pub userhash: Option<bool>,
}The challenge for Digest authentication
Fields
realm: Option<String>
realm of the authentication
domain: Option<Vec<Url>>
domains of the authentication
nonce: Option<String>
the nonce used in authentiaction
opaque: Option<String>
a string data specified by the server
stale: Option<bool>
a flag indicating that the previous request from the client was rejected because the nonce value was stale.
algorithm: Option<Algorithm>
the algorithm used to produce the digest and unkeyed digest. if not present, it is assumed to be Md5
qop: Option<Vec<Qop>>
"quality of protection" values supported by the server
userhash: Option<bool>
this is an OPTIONAL parameter that is used by the server to indicate that it supports username hashing. default is false if not present